#!/bin/sh
#
# clean.sh
#

make clean

DIR=lib
if [ -d $DIR ]; then
	cd $DIR
	make clean
	cd ../
fi

DIR=sbin
if [ -d $DIR ]; then
	cd $DIR
	make clean
	cd ../
fi

DIR=command
if [ -d $DIR ]; then
	cd $DIR
	make clean
	cd ../
fi

DIR=test
if [ -d $DIR ]; then
	cd $DIR
	make clean
	cd ../
fi

DIR=module/console.mod
if [ -d $DIR ]; then
	cd $DIR
	make clean
	cd ../../
fi

DIR=module/ata.mod
if [ -d $DIR ]; then
	cd $DIR
	make clean
	cd ../../
fi

DIR=module/test
if [ -d $DIR ]; then
	cd $DIR
	make clean
	cd ../../
fi

if [ -d copy ]; then
	rm copy/bin/* -vf
	rm copy/usr/bin/* -vf
	rm copy/sbin/* -vf
	rm copy/module/* -vf
	rm copy/test/* -vf
	rm copy/usr/include/* -vrf
fi
